@@ -22,21 +22,13 @@
 
 #include "chinesecalendar.h"
 
-Cnote *note = 0;
 
 ChineseCalendar::ChineseCalendar(QWidget *parent)
     : QWidget(parent)
 {
     setupUi(this);
 
-    note = new Cnote;
-    QDesktopWidget desktop;
-    int width = desktop.screenGeometry().width();
-    int height = desktop.screenGeometry().height();
-    note->setGeometry(QRect(width-400,80,224,280));
-    note->hide();
-
-    bg = new QPixmap(":/img/chinesecalendarBGyellow.png");
+    bg = new QPixmap(":/img/chinesecalendarBGblue.png");
     icon = QIcon(":/img/icon.png");
     icon64 = QIcon(":/img/chinesecalendar-64.png");
     mycalendat=new CCBO;
@@ -48,8 +40,6 @@ ChineseCalendar::ChineseCalendar(QWidget *parent)
     connect(monthCombo, SIGNAL(activated(int)), this, SLOT(setMonth(int)));
     connect(YearSelect, SIGNAL(currentIndexChanged(int)), this, SLOT(setYear(int)));
     connect(this->backtotoday, SIGNAL(clicked()), this, SLOT(backtoday()));
-    connect(note,SIGNAL(save(QString)),this,SLOT(savedata(QString)));
-
 
 
     this->TbnextMonth->setStyleSheet("QPushButton{background-color:transparent;color:rgb(200,200,150);}QPushButton:hover{color:rgb(255,255,255);}");
@@ -149,17 +139,15 @@ ChineseCalendar::ChineseCalendar(QWidget *parent)
        ji = QString("").append(chinesejilist.at(0)).append("\n");
     this->label_18->setText(ji);
 
-    QString cnote=mycalendat->ctcl_displaydata(day.year(),day.month(),day.day(),cnote);
+    QString cnote=mycalendat->ctcl_displaydata(day.year(),day.month(),day.day());
     QString haveplan=QString("今日有行程安排");
     QString noplan=QString("今日无行程安排");
-    QStringList cnotelist=cnote.split(" ");
-    int count=cnotelist.count();
-    QString space=QString("");
-    while(count>0&&(cnotelist.at(count-1)==space))
+    int num=cnote.count();
+    while( num > 0 && cnote.at(num-1).isSpace())
     {
-        count--;
+        num--;
     }
-    if(cnote.isEmpty()||count==0)
+    if(cnote.isEmpty() || num == 0)
         this->label_19->setText(noplan);
     else
         this->label_19->setText(haveplan);
@@ -179,14 +167,18 @@ ChineseCalendar::ChineseCalendar(QWidget *parent)
 
     pa.setColor(QPalette::WindowText,Qt::black);
     this->label_18->setPalette(pa);
-    this->label_19->setPalette(pa);
 
-    pa.setColor(QPalette::WindowText,Qt::red);
+    pa.setColor(QPalette::WindowText,QColor(235,74,20));
     this->label_10->setPalette(pa);
-    this->label_11->setPalette(pa);
     this->label_12->setPalette(pa);
     this->label_13->setPalette(pa);
     this->label_14->setPalette(pa);
+
+    pa.setColor(QPalette::WindowText,Qt::white);
+    this->label_19->setPalette(pa);
+
+    pa.setColor(QPalette::WindowText,Qt::red);
+    this->label_11->setPalette(pa);
     this->label_17->setPalette(pa);
 
     map = new QMap<QString, DateItem *>();
@@ -449,6 +441,15 @@ ChineseCalendar::ChineseCalendar(QWidget *parent)
 
 
     this->createTray();
+
+
+    note = new Cnote;
+    QDesktopWidget desktop;
+    int width = desktop.screenGeometry().width();
+    note->setGeometry(QRect(width-400,80,224,280));
+    connect(note,SIGNAL(save(QString)),this,SLOT(savedata(QString)));
+    note->hide();
+
 }
 
 ChineseCalendar::~ChineseCalendar()
@@ -464,9 +465,10 @@ void ChineseCalendar::setclickday(QString day)
     int today = clickday;
     QString dateplan = QString("%1月%2日计划安排").arg(this->monthCombo->currentText()).arg(day);
     QString data;
-    data=mycalendat->ctcl_displaydata(year,month,today,data);
+    data=mycalendat->ctcl_displaydata(year,month,today);
     note->textedit->setText(data);
     note->datelabel->setText(dateplan);
+    note->exec();
 }
 
 void ChineseCalendar::savedata(QString data)
@@ -474,8 +476,8 @@ void ChineseCalendar::savedata(QString data)
     int year = this->YearSelect->currentText().toInt();
     int month = this->monthCombo->currentText().toInt();
     int day = clickday;
-    QString note = data;  
     mycalendat->ctcl_savenote(year,month,day,data);
+    note->hide();
 
 }
 
@@ -518,6 +520,7 @@ void ChineseCalendar::createTray()
     this->trayIcon = new QSystemTrayIcon(this);
     this->trayIcon->setIcon(icon);
     this->trayIcon->setContextMenu(trayMenu);
+    connect(this->trayIcon, SIGNAL(activated(QSystemTrayIcon::ActivationReason)), this, SLOT(handle_trayIcon_activated(QSystemTrayIcon::ActivationReason)));
     this->trayIcon->show();
 }
 
@@ -784,15 +787,13 @@ void ChineseCalendar::resetcalendardate(QString day)
     QString cnote=QString("");
     QString haveplan=QString("今日有行程安排");
     QString noplan=QString("今日无行程安排");
-    cnote=mycalendat->ctcl_displaydata(date.year(),date.month(),date.day(),cnote);
-    QStringList cnotelist=cnote.split(" ");
-    QString space=QString("");
-    int count=cnotelist.count();
-    while(count>0&&(cnotelist.at(count-1)==space))
+    cnote=mycalendat->ctcl_displaydata(date.year(),date.month(),date.day());
+    int num=cnote.count();
+    while( num > 0 && cnote.at(num-1).isSpace())
     {
-        count--;
+        num--;
     }
-    if(cnote.isEmpty()||count==0)
+    if(cnote.isEmpty() || num == 0)
         this->label_19->setText(noplan);
     else
         this->label_19->setText(haveplan);
@@ -879,6 +880,8 @@ void ChineseCalendar::setCalendar()
           else
               mycday=c.sterm;
         }
+        if(c.ischoliday)
+            mycday=c.choliday;
         int day = date.day();
         if (weekDay == 7)
             weekDay = 0;
@@ -1148,6 +1151,18 @@ void ChineseCalendar::on_TbnextYear_clicked()
         YearSelect->setCurrentIndex(YearSelect->currentIndex()+1);
 }
 
+void ChineseCalendar::handle_trayIcon_activated(QSystemTrayIcon::ActivationReason reason)
+{
+    switch(reason)
+    {
+        case QSystemTrayIcon::Trigger:
+            this->showOrHide();
+            break;
+        default:
+            ;
+    }
+}
+
 void ChineseCalendar::showOrHide()
 {
     if(this->isHidden())
