@@ -58,6 +58,7 @@ private:
     void setItemLayout();
     void resetItemLayout();
     CCalendar fixshengxiao(QDate);
+    Cnote *note;
 
     void paintEvent(QPaintEvent *);
 
@@ -80,6 +81,7 @@ public slots:
     void setTime();
     void resetcalendardate(QString);
     void backtoday();
+    void handle_trayIcon_activated(QSystemTrayIcon::ActivationReason reason);
     void showOrHide();
     void setMode();
     void savedata(QString);
