@@ -3,8 +3,9 @@
 
 #include <QWidget>
 #include <QtGui>
+#include <QDialog>
 
-class Cnote : public QWidget
+class Cnote : public QDialog
 {
     Q_OBJECT
 public:
@@ -14,13 +15,12 @@ public:
     void paintEvent(QPaintEvent *);
     QPoint dragPos;
     QTextEdit *textedit;
-    QLineEdit *datelabel;
+    QLabel *datelabel;
 protected:
     void  mouseMoveEvent(QMouseEvent *event);
     void  mousePressEvent(QMouseEvent *event);
     void  mouseReleaseEvent(QMouseEvent *event);
 private:
-//    QTextEdit *textedit;
     QPushButton *ok;
     QPushButton *cancel;
     QPushButton *clearplan;
