@@ -21,7 +21,7 @@
  */
 
 #include "dateitem.h"
-extern Cnote *note;
+//extern Cnote *note;
 
 DateItem::DateItem(QWidget *parent) :
     QWidget(parent),
@@ -131,7 +131,7 @@ void DateItem::clickday()
     if(!ui->label->text().isNull())
     {
         emit day(ui->label->text());
-        note->show();
+//        note->show();
     }
 }
 
