@@ -22,12 +22,20 @@
 
 #include "datemaskwidget.h"
 #include <QDebug>
-
+#include "chinesecalendar.h"
 DateMaskWidget::DateMaskWidget(QWidget *parent) :
-    QWidget(parent){}
+    QWidget(parent)
+{
+
+}
 
 void DateMaskWidget::mousePressEvent(QMouseEvent *ev)
 {
-    emit clicked();
+    if( ev->button() == Qt::LeftButton)
+        emit clicked();
+    if( ev->button() == Qt::LeftButton && ev->type() == QEvent::MouseButtonDblClick)
+    {
+        emit clickday();
+    }
     ev->ignore();
 }
